==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/backup/kotlin/inputs/PlanRuleLifecycleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.backup.kotlin.inputs

import com.pulumi.aws.backup.inputs.PlanRuleLifecycleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property coldStorageAfter Specifies the number of days after creation that a recovery point is moved to cold storage.
 * @property deleteAfter Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
 */
public data class PlanRuleLifecycleArgs(
    public val coldStorageAfter: Output<Int>? = null,
    public val deleteAfter: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.backup.inputs.PlanRuleLifecycleArgs> {
    override fun toJava(): com.pulumi.aws.backup.inputs.PlanRuleLifecycleArgs =
        com.pulumi.aws.backup.inputs.PlanRuleLifecycleArgs.builder()
            .coldStorageAfter(coldStorageAfter?.applyValue({ args0 -> args0 }))
            .deleteAfter(deleteAfter?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PlanRuleLifecycleArgs].
 */
@PulumiTagMarker
public class PlanRuleLifecycleArgsBuilder internal constructor() {
    private var coldStorageAfter: Output<Int>? = null

    private var deleteAfter: Output<Int>? = null

    /**
     * @param value Specifies the number of days after creation that a recovery point is moved to cold storage.
     */
    @JvmName("edaylnvgdrgvadym")
    public suspend fun coldStorageAfter(`value`: Output<Int>) {
        this.coldStorageAfter = value
    }

    /**
     * @param value Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
     */
    @JvmName("loxoahbcxjiwsfvw")
    public suspend fun deleteAfter(`value`: Output<Int>) {
        this.deleteAfter = value
    }

    /**
     * @param value Specifies the number of days after creation that a recovery point is moved to cold storage.
     */
    @JvmName("fxywdlblublfptwf")
    public suspend fun coldStorageAfter(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.coldStorageAfter = mapped
    }

    /**
     * @param value Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
     */
    @JvmName("foavqxdavowxuchx")
    public suspend fun deleteAfter(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteAfter = mapped
    }

    internal fun build(): PlanRuleLifecycleArgs = PlanRuleLifecycleArgs(
        coldStorageAfter = coldStorageAfter,
        deleteAfter = deleteAfter,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/backup/kotlin/inputs/PlanRuleLifecycleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.backup.kotlin.inputs

import com.pulumi.aws.backup.inputs.PlanRuleLifecycleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property coldStorageAfter Specifies the number of days after creation that a recovery point is moved to cold storage.
 * @property deleteAfter Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
 * @property optInToArchiveForSupportedResources This setting will instruct your backup plan to transition supported resources to archive (cold) storage tier in accordance with your lifecycle settings.
 */
public data class PlanRuleLifecycleArgs(
    public val coldStorageAfter: Output<Int>? = null,
    public val deleteAfter: Output<Int>? = null,
    public val optInToArchiveForSupportedResources: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.aws.backup.inputs.PlanRuleLifecycleArgs> {
    override fun toJava(): com.pulumi.aws.backup.inputs.PlanRuleLifecycleArgs =
        com.pulumi.aws.backup.inputs.PlanRuleLifecycleArgs.builder()
            .coldStorageAfter(coldStorageAfter?.applyValue({ args0 -> args0 }))
            .deleteAfter(deleteAfter?.applyValue({ args0 -> args0 }))
            .optInToArchiveForSupportedResources(
                optInToArchiveForSupportedResources?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [PlanRuleLifecycleArgs].
 */
@PulumiTagMarker
public class PlanRuleLifecycleArgsBuilder internal constructor() {
    private var coldStorageAfter: Output<Int>? = null

    private var deleteAfter: Output<Int>? = null

    private var optInToArchiveForSupportedResources: Output<Boolean>? = null

    /**
     * @param value Specifies the number of days after creation that a recovery point is moved to cold storage.
     */
    @JvmName("ukkcxdrntjaiinsc")
    public suspend fun coldStorageAfter(`value`: Output<Int>) {
        this.coldStorageAfter = value
    }

    /**
     * @param value Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
     */
    @JvmName("fxwmyfrrwrxrampi")
    public suspend fun deleteAfter(`value`: Output<Int>) {
        this.deleteAfter = value
    }

    /**
     * @param value This setting will instruct your backup plan to transition supported resources to archive (cold) storage tier in accordance with your lifecycle settings.
     */
    @JvmName("wwdlapkhemvydfgq")
    public suspend fun optInToArchiveForSupportedResources(`value`: Output<Boolean>) {
        this.optInToArchiveForSupportedResources = value
    }

    /**
     * @param value Specifies the number of days after creation that a recovery point is moved to cold storage.
     */
    @JvmName("kleptyemkmoysnfv")
    public suspend fun coldStorageAfter(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.coldStorageAfter = mapped
    }

    /**
     * @param value Specifies the number of days after creation that a recovery point is deleted. Must be 90 days greater than `cold_storage_after`.
     */
    @JvmName("kdvoagkmryfygvlr")
    public suspend fun deleteAfter(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteAfter = mapped
    }

    /**
     * @param value This setting will instruct your backup plan to transition supported resources to archive (cold) storage tier in accordance with your lifecycle settings.
     */
    @JvmName("dfvchlabqugsspha")
    public suspend fun optInToArchiveForSupportedResources(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.optInToArchiveForSupportedResources = mapped
    }

    internal fun build(): PlanRuleLifecycleArgs = PlanRuleLifecycleArgs(
        coldStorageAfter = coldStorageAfter,
        deleteAfter = deleteAfter,
        optInToArchiveForSupportedResources = optInToArchiveForSupportedResources,
    )
}
